NetIQ/Microfocus AccessManager (NAM)
------------------------------------

The following AccessManager settings are available:

.. code-block:: python

    SOCIALACCOUNT_PROVIDERS = {
        'netiq': {
            'NETIQ_URL': 'https://my.identity.provider.example.org',
        }
    }


App registration (get your key and secret here) is done by the administrator of your NetIQ/Microfocus AccessManager.
